==> qarte-dmo_4.17.2.orig.tar.gz: qarte-4.17.2/data.py <==
# -*- coding: utf-8 -*-

# data.py
# This file is part of qarte 4
#    
# Author: Vincent Vande Vyvre <vincent.vandevyvre@oqapy.eu>
# Copyright: 2011-2022 Vincent Vande Vyvre
# Licence: GPL3
# Home page: https://launchpad.net/qarte
#
# Constants list, XXX don't forget to update VERSION if needed.


VERSION = (4, 17, 2)

VERSION_STR = '.'.join(str(i) for i in VERSION)

USER_AGENT = "Qarte/%s" % VERSION_STR

DEFAULT_PREFS = {'version': VERSION,
                'lang': 'fr',
                'load_pages': [True, False],
                'video_player': True,
                'videos_folder': None, 
                'music_folder': None,
                'add_date': False,
                'pitch_plus': True,
                'pitch_plus_unique': 1, 
                'pitch_plus_format': 'txt',
                'pitch_live': True,
                'pitch_live_unique': 1, 
                'pitch_live_format': 'html',
                'copythumb_plus': False,
                'copythumb_live': False,
                'update': True, 
                'thumb1': 160, 
                'thumb2': 80, 
                'notify': True,  
                'size': (900, 700),
                'tv_quality': 720,
                'live_quality': 'HTTP_EQ_1',
                'show_rpm': False,
                'cur_cat': 'Jazz & Blues', 
                'mini': 220, 
                'maxi': 325, 
                'news': [False, True, True, False, True],
                'crontab_cmd': 'export DISPLAY=:0 & LC_CTYPE="<lang>" Lang="<lang>" qarte -a <ID> >> "<log>" 2>&1',
                'filter_keys': []}

ARTE_TV = "https://www.arte.tv/fr/guide/DAY/"

DAYS_FR = ['Dimanche', 'Lundi', 'Mardi', 'Mercredi', 'Jeudi',
                    'Vendredi', 'Samedi', 'Tous les jours']

DAYS_DE = ['Sonntag', 'Montag', 'Dienstag', 'Mittwoch',
                    'Donnerstag', 'Freitag', 'Samstag',
                    'Alle Tage']

SERIALS_FR = ['28 minutes', '360 - GEO', 'ARTE Journal', 
                'ARTE Reportage', 'Court-Circuit', 'Karambolage',
                'Le Dessous des Cartes', 'Metropolis', 'Personne ne bouge',
                'Philosophie', 'Square', 'Tracks', 'X:enius',
                'Yourope']

SERIALS_DE = ['28 Minuten', '360° - GEO-Reportage', 
                'ARTE Journal','ARTE Reportage',
                'Geschichte am Mittwoch', 'Karambolage', 
                'Metropolis', 'Mit offenen Karten', 'Philosophie', 
                'Square', 'Tracks', 'X:enius', 'Yourope']

FR_CATEGORIES = ['Classique', 'Jazz & Blues', 'Pop rock & Electro',
                    'Théâtre & Danse', 'Musiques du monde', 'Tracks',
                    'La Blogothèque']

DE_CATEGORIES = ['Klassik', 'Jazz & Blues', 'Pop, Rock, Electro',
                    'Theater & Tanz', 'World Music', 'Tracks',
                    'La Blogothèque']

CATEGORIES = {'fr': {'Classique': 'Classique',
                    'Jazz & Blues': 'Jazz___Blues',
                    'Pop rock & Electro': 'Pop_rock___Electro',
                    'Théâtre & Danse': 'Theatre___Danse',
                    'Musiques du monde': 'Musiques_du_monde',
                    'Tracks': 'tracks',
                    'La Blogothèque': 'blogo',
                    'News': 'News'},
            'de': {'Klassik': 'Klassik_',
                    'Jazz & Blues': 'Jazz__Blues',
                    'Pop, Rock, Electro': 'Pop__Rock__Electro',
                    'Theater & Tanz': 'Theater___Tanz_',
                    'World Music': 'World_Music',
                    'Tracks': 'tracks',
                    'La Blogothèque': 'blogo',
                    'News': 'News'}}

URLS_FR = {'Classique': ['http://concert.arte.tv/fr/videos/musique-classique',
                          'http://download.liveweb.arte.tv/o21/liveweb/rss/home-4-fr.rss', 
                          ],
            'Jazz & Blues': ['http://concert.arte.tv/fr/videos/jazz',
                              'http://download.liveweb.arte.tv/o21/liveweb/rss/home-34-fr.rss',
                              'http://download.liveweb.arte.tv/o21/liveweb/rss/partner-229-fr.rss', 
                              ],
            'Pop rock & Electro': ['http://concert.arte.tv/fr/videos/rockpop',
                                    'http://download.liveweb.arte.tv/o21/liveweb/rss/home-25-fr.rss', 
                                    ],
            'Théâtre & Danse': ['http://concert.arte.tv/fr/videos/danse',
                                 'http://download.liveweb.arte.tv/o21/liveweb/rss/home-10-fr.rss',  
                                 ],
            'Musiques du monde': ['http://concert.arte.tv/fr/videos/musiques-du-monde',
                                   'http://download.liveweb.arte.tv/o21/liveweb/rss/home-22-fr.rss',
                                   'http://download.liveweb.arte.tv/o21/liveweb/rss/partner-6-fr.rss', 
                                   ],
            'Tracks': ['http://download.liveweb.arte.tv/o21/liveweb/rss/partner-291-fr.rss'],
            'La Blogothèque': ['http://download.liveweb.arte.tv/o21/liveweb/rss/partner-13-fr.rss']}

URLS_DE = {'Klassik': ['http://download.liveweb.arte.tv/o21/liveweb/rss/home-5-de.rss',
                          'http://concert.arte.tv/de/videos/klassik'],
            'Jazz & Blues': ['http://download.liveweb.arte.tv/o21/liveweb/rss/home-35-de.rss',
            'http://download.liveweb.arte.tv/o21/liveweb/rss/partner-229-de.rss',
                              'http://concert.arte.tv/de/videos/jazz'],
            'Pop, Rock, Electro': ['http://download.liveweb.arte.tv/o21/liveweb/rss/home-26-de.rss',
                                    'http://concert.arte.tv/de/videos/rockpop'],
            'Theater & Tanz': ['http://download.liveweb.arte.tv/o21/liveweb/rss/home-11-de.rss',
                                 'http://concert.arte.tv/de/videos/tanz'],
            'World Music': ['http://download.liveweb.arte.tv/o21/liveweb/rss/home-23-de.rss',
                             'http://download.liveweb.arte.tv/o21/liveweb/rss/partner-6-de.rss',
                                   'http://concert.arte.tv/de/videos/worldmusic'],
            'Tracks': ['http://download.liveweb.arte.tv/o21/liveweb/rss/partner-291-de.rss'],
            'La Blogothèque': ['http://download.liveweb.arte.tv/o21/liveweb/rss/partner-13-de.rss']}

FESTIVALS = {'fr': {'Les Trans Musicales de Rennes': 'trans',
                    'Hellfest': 'hell',
                    'La Folle Journée de Nantes': 'nantes',
                    'Africa Festival': 'africa',
                    "La Roque d'Anthéron": 'roque',
                    'Les Suds à Arles': 'suds',
                    "Festival d'Aix-en-Provence": 'aix',
                    'Les Vielles Charrues': 'charrues',
                    'Rio Locos': 'locos',
                    'Festival de Saint Denis': 'denis',
                    'Les nuits du Sud': 'nuitsud',
                    'Mahler Festival': 'mahler',
                    'Europavox': 'europa',
                    'Jazz à la Vilette': 'villette',
                    'Dour': 'dour',
                    'Au Fil des Voix': 'filvoix'},
            'de': {'Les Trans Musicales de Rennes': 'trans',
                    'Hellfest': 'hell',
                    'La Folle Journée de Nantes': 'nantes',
                    'Africa Festival': 'africa',
                    "La Roque d'Anthéron": 'roque',
                    'Les Suds à Arles': 'suds',
                    "Festival d'Aix-en-Provence": 'aix',
                    'Les Vielles Charrues': 'charrues',
                    'Rio Locos': 'locos',
                    'Festival de Saint Denis': 'denis',
                    'Les nuits du Sud': 'nuitsud',
                    'Mahler Festival': 'mahler',
                    'Europavox': 'europa',
                    'Jazz à la Vilette': 'villette',
                    'Dour': 'dour',
                    'Au Fil des Voix': 'filvoix'}}

ICONS = {'plus': {},
        'live': {'clson': 'medias/classic_on.png',
                'clsoff': 'medias/classic_off.png',
                'jazon': 'medias/jazz_on.png',
                'jazoff': 'medias/jazz_off.png',
                'rockon': 'medias/rock_on.png',
                'rockoff': 'medias/rock_off.png',
                'thton': 'medias/theater_on.png',
                'thtoff': 'medias/theater_off.png',
                'wrlon': 'medias/world_on.png',
                'wrloff': 'medias/world_off.png',
                'nwon': 'medias/news_on.png',
                'nwoff': 'medias/news_off.png',
                'blogon': 'medias/blogo_on.png',
                'blogoff': 'medias/blogo_off.png',
                'trkon': 'medias/tracks_on.png',
                'trkoff': 'medias/tracks_off.png',
                'blgon': 'medias/blogo_on.png',
                'blgoff': 'medias/blogo_off.png',
                'introdon': 'medias/introd_on.png',
                'introdoff': 'medias/introd_off.png',
                'rdron': 'medias/rdr_on.png',
                'rdroff': 'medias/rdr_off.png',
                'oprfon': 'medias/oprf_on.png',
                'oprfoff': 'medias/oprf_off.png',
                'odpon': 'medias/odp_on.png',
                'odpoff': 'medias/odp_off.png',
                'cdmon': 'medias/cdm_on.png',
                'cdmoff': 'medias/cdm_off.png',
                'lngon': 'medias/lounge_on.png',
                'lngoff': 'medias/lounge_off.png'}}

==> qarte-dmo_5.1.0.orig.tar.gz: qarte-5.1.0/data.py <==
# data.py
# This file is part of qarte 5
#    
# Author: Vincent Vande Vyvre <vincent.vandevyvre@oqapy.eu>
# Copyright: 2011-2022 Vincent Vande Vyvre
# Licence: GPL3
# Home page: https://launchpad.net/qarte
#
# Constants list, XXX don't forget to update VERSION if needed.


VERSION = (5, 1, 0)

VERSION_STR = '.'.join(str(i) for i in VERSION)

ARTE_TV = "https://www.arte.tv/fr/guide/DAY/"

USER_AGENT = "Qarte/%s" % VERSION_STR

CONFIG_DEFAULT = {'version': VERSION,
                'lang': 'fr',
                'load_pages': [True, False],
                'video_player': True,
                'videos_folder': None, 
                'music_folder': None,
                'add_date': False,
                'add_subtitle': False,
                'merge_files': True,
                'proxy': None,
                'pitch_plus': True,
                'pitch_plus_unique': 1, 
                'pitch_plus_format': 'txt',
                'pitch_live': True,
                'pitch_live_unique': 1, 
                'pitch_live_format': 'html',
                'copythumb_plus': False,
                'copythumb_live': False,
                'update': True, 
                'thumb1': 160, 
                'thumb2': 80, 
                #'notify': True,  
                'size': (900, 700),
                'tv_quality': 720,
                'live_quality': 'HTTP_EQ_1',
                #'show_rpm': False,
                'cur_cat': 'Jazz & Blues', 
                'mini': 220, 
                'maxi': 325, 
                #'news': [False, True, True, False, True],
                'crontab_cmd': 'export DISPLAY=:0 & LC_CTYPE="<lang>" Lang="<lang>" qarte -a <ID> >> "<log>" 2>&1',
                'filter_keys': []}
